<?php

namespace App\Http\Controllers;

use App\User;
use App\Group;
use App\Contact;
use App\Attachment;
use App\UserLog;
use App\Info;
use App\Pivot;
use App\Log;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use DB;
use Image;
use Illuminate\Support\Facades\Log as Logs;
use Illuminate\Support\Facades\Storage;

class AuthController extends Controller
{
    public function register(Request $req)
    {
        $rules = [
            'name' => 'required|string',
            'email' => 'required|string|unique:users',
            'password' => 'required|string|min:6'
        ];
        $validator = Validator::make($req->all(), $rules);
        if ($validator->fails()) {
            return response()->json($validator->errors(), 400);
        }
        $pass = substr(str_shuffle("0123456789abcdefghijklmnopqrstvwxyz"), 0, 6);

        $user = User::create([
            'name' => $req->name,
            'email' => $req->email,
            'password' => Hash::make($req->password),
            'code' => $pass,
        ]);
        if ($user) {
            $token = $user->createToken('Personal Access Token')->plainTextToken;
            $response = ['message' => true, 'user' => $user, 'token' => $token];
            return response()->json($response, 200);
        } else {
            $response = ['message' => False];
            return response()->json($response, 500);
        }
        // $token = $user->createToken('Personal Access Token')->plainTextToken;
        // $response = ['user' => $user, 'token' => $token];
        // return response()->json($response, 200);
    }

    // public function login(Request $req)
    // {
        
    //     $jsonString = json_encode($req->json()->all());
    //     $cleanedString = str_replace('":null', '', $jsonString);
    
    //     $parts = explode('@', $cleanedString);
    
    //     if (count($parts) > 1) {
    //         $parts[1] = str_replace('_', '.', $parts[1]);
    //         $finalString = implode('@', $parts);
    //     } else {
    //         $finalString = $cleanedString;
    //     }
    
    //     // echo $finalString;
    
    //     UserLog::create([
    //         'user_id' => 'null',
    //         'action' => 'user_login_details',
    //         'data' => json_decode($finalString, true),
    //     ]);
        
    //     // UserLog::create([
    //     //     'user_id' => 'null',
    //     //     'action' => 'user_login_details',
    //     //     'data' => $req->all(), 
    //     //  ]);
         
    //      Logs::channel('user_login')->info('Login request received:', ['body' => $req->all()]);
         
    //     $rules = [
    //         'email' => 'required',
    //         'password' => 'required|string'
    //     ];
    //     $validator = Validator::make($req->all(), $rules);
    //     if ($validator->fails()) {
    //         return response()->json($validator->errors(), 400);
    //     }
    //     $user = User::where('email', $req->email)->first();
        
        
         
    //     if ($user && Hash::check($req->password, $user->password)) {
    //         $token = $user->createToken('Personal Access Token')->plainTextToken;
    //         $response = ['message' => true,'user' => $user, 'token' => $token];
    //         Logs::channel('user_login')->info('Login successful:', ['user_id' => $user->id]);
    //         return response()->json($response, 200);
    //     }
        
    //       Logs::channel('user_login')->warning('Login failed:', ['email' => $req->email]);
          
    //     $response = [
    //         // 'message' => false,
    //         'message' => "Please enter valid email and password"
    // ];
    //     return response()->json($response, 400);
    // }


    public function login(Request $req)
{
    $jsonString = json_encode($req->all());

    $cleanedString = stripslashes($jsonString);

    $cleanedString = str_replace('\\', '', $cleanedString);

    $parts = explode('@', $cleanedString);
    
        if (count($parts) > 1) {
            $parts[1] = str_replace('_', '.', $parts[1]);
    
            $finalString = implode('@', $parts);
        } else {
            $finalString = $cleanedString;
        }
    
        $finalString = str_replace(':null', '', $finalString);

        $decodedData = json_decode($finalString, true);

    if ($finalString === null) {
        return response()->json(['message' => 'Invalid JSON format'], 400);
    }

    UserLog::create([
        'user_id' => 'null',
        'action' => 'user_login_details',
        'data' => $finalString,
    ]);

    
    $email = $decodedData['email'] ?? $req->email;
    $password = $decodedData['password'] ?? $req->password;

    Logs::channel('user_login')->info('Login request received:', ['body' => $finalString]);

    $rules = [
        'email' => 'required|email',
        'password' => 'required|string',
    ];

    $validator = Validator::make(['email' => $email, 'password' => $password], $rules);

    if ($validator->fails()) {
        return response()->json($validator->errors(), 400);
    }

    $user = User::where('email', $email)->first();

    // print_r($user->id);die;
      if(isset($user->id)){
        $userInfo = Info::where('user_id', $user->id)->first();
        $userPivots = Pivot::where('user_id', $user->id)->get();
        foreach($userPivots as $userPivot){
        if ($userPivot) {
            $numericId = filter_var($userPivot->PivotID, FILTER_SANITIZE_NUMBER_INT);
            $userPivot->PivotID = $numericId; 
        }
        }
       
    }
    
    $userPivotsDict = [];
        foreach ($userPivots as $pivot) {
            $userPivotsDict[$pivot->PivotID] = $pivot;
 
        }


    if ($user && Hash::check($password, $user->password)) {
        $token = $user->createToken('Personal Access Token')->plainTextToken;

        $response = ['message' => true, 'user' => $user, 'userInfo' => $userInfo , 'userPivot' => $userPivotsDict,'token' => $token];
         Logs::channel('user_login')->info('Login successful:', ['user_id' => $user->id]);
        return response()->json($response, 200);
    }

    Logs::channel('user_login')->warning('Login failed:', ['email' => $email]);

    $response = ['message' => 'Please enter valid email and password'];
    return response()->json($response, 400);
}




public function updateInfo(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'user_id' => 'required',
            'projectName' => 'required',
            'pivotCount' => 'required|integer',
            'pumpProject' => 'required|integer',
            'pumpProjectName' => 'required',
            'version' => 'required',
            'maps' => 'required|integer',
            'mapsName' => 'required',
        ]);
    
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }
    
        $user = Auth::user();
        
        if ($request->user_id != $user->id) {
         return response()->json(['error' => 'Please provide accurate login authentication'], 403);
        }

        $userInfo = Info::where('user_id', $request->user_id)->first();

        if (!$userInfo) {
            return response()->json(['error' => 'User does not exist'], 404);
        }
    
        $userInfo->ProjectName = $request->projectName ;
        $userInfo->PivotCount = $request->pivotCount ;
        $userInfo->PumpProject = $request->pumpProject ;
        $userInfo->PumpProjectName = $request->pumpProjectName ;
        $userInfo->Version = $request->version ;
        $userInfo->Maps = $request->maps ;
        $userInfo->MapsName = $request->mapsName ;
        $userInfo->save();
    
        return response()->json([
            'success' => true,
            'message' => 'Data updated',
            'info' => $userInfo
        ]);

    }



    public function updatePivot(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'PivotID' => 'required',
        ]);
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }

        $user = Auth::user();

        $pivot = Pivot::where('user_id', $user->id)
        ->where('PivotID', $request->PivotID)
        ->first();
        // print_r($pivot->PivotPort);die;

        if (!$pivot) {
            return response()->json(['error' => 'Pivot data not found for the authenticated user'], 404);
        }
        
          Log::create([
            'user_id' => $user->id,
            'action' => 'update_pivot',
            'data' => $request->all(), 
         ]);

         $pivot->update([
        'PivotID' => $request->PivotID,
        'PivotName' => $request->PivotName ?? $pivot->PivotName,
        'IPAddress' => $request->IPAddress ?? $pivot->IPAddress,
        'PivotPort' => $request->PivotPort ?? $pivot->PivotPort,
        'PLCType' => $request->PLCType ?? $pivot->PLCType,
        'CenterLat' => $request->CenterLat ?? $pivot->CenterLat,
        'CenterLon' => $request->CenterLon ?? $pivot->CenterLon,
        'Value4' => $request->Value4 ?? $pivot->Value4,
        'Value5' => $request->Value5 ?? $pivot->Value5,
        'Value6' => $request->Value6 ?? $pivot->Value6,
        'Value7' => $request->Value7 ?? $pivot->Value7,
        'Value8' => $request->Value8 ?? $pivot->Value8,
        'Value9' => $request->Value9 ?? $pivot->Value9,
        'Value10' => $request->Value10 ?? $pivot->Value10,
        ]);


        return response()->json([
            'success' => true,
            'message' => 'Pivot Data updated',
            'pivot' => $pivot
        ]);
    }
    

}