<?php

namespace App\Http\Controllers;

use App\User;
use App\Group;
use App\Contact;
use App\Attachment;
use App\Survey;
use App\Info;
use App\Participant;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Auth;
use DB;
use Image;
use Illuminate\Support\Facades\Storage;

class AuthController extends Controller
{
    public function register(Request $req)
    {
        $rules = [
            'name' => 'required|string',
            'email' => 'required|string|unique:users',
            'password' => 'required|string|min:6'
        ];
        $validator = Validator::make($req->all(), $rules);
        if ($validator->fails()) {
            return response()->json($validator->errors(), 400);
        }
        $pass = substr(str_shuffle("0123456789abcdefghijklmnopqrstvwxyz"), 0, 6);

        $user = User::create([
            'name' => $req->name,
            'email' => $req->email,
            'password' => Hash::make($req->password),
            'code' => $pass,
        ]);
        if ($user) {
            $token = $user->createToken('Personal Access Token')->plainTextToken;
            $response = ['message' => true, 'user' => $user, 'token' => $token];
            return response()->json($response, 200);
        } else {
            $response = ['message' => False];
            return response()->json($response, 500);
        }
        // $token = $user->createToken('Personal Access Token')->plainTextToken;
        // $response = ['user' => $user, 'token' => $token];
        // return response()->json($response, 200);
    }

    public function login(Request $req)
    {
        $rules = [
            'email' => 'required',
            'password' => 'required|string'
        ];
        $validator = Validator::make($req->all(), $rules);
        if ($validator->fails()) {
            return response()->json($validator->errors(), 400);
        }
        $user = User::where('email', $req->email)->first();
        if ($user && Hash::check($req->password, $user->password)) {
            $token = $user->createToken('Personal Access Token')->plainTextToken;
            $response = ['message' => true,'user' => $user, 'token' => $token];
            return response()->json($response, 200);
        }
        $response = [
            // 'message' => false,
            'message' => "Please enter valid email and password"
    ];
        return response()->json($response, 400);
    }




public function update(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'user_id' => 'required',
        ]);
    
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 400);
        }
    
        $userInfo = Info::where('user_id', $request->user_id)->first();

        if (!$userInfo) {
            return response()->json(['error' => 'User does not exist'], 404);
        }
    
        $userInfo->ProjectName = $request->projectName;
        $userInfo->PivotCount = $request->pivotCount;
        $userInfo->PumpProject = $request->pumpProject;
        $userInfo->PumpProjectName = $request->pumpProjectName;
        $userInfo->Version = $request->version;
        $userInfo->Maps = $request->maps;
        $userInfo->MapsName = $request->mapsName;
    
        $userInfo->save();
    
        return response()->json([
            'success' => true,
            'message' => 'Data updated inserted',
            'survey' => $userInfo
        ]);

    }

}